


local function SetValue(info,value) 
	KeystoneRollCall.db.global[info.arg] = value
end

local function GetValue(info) 
	return KeystoneRollCall.db.global[info.arg] 
end

local defaultOptions = {
	version = 1,
	minimapIcon = {hide = false},
	printPlayerNewKey = true,
	printPlayerBestRun = true,
	printOthersNewKeys = true,
	printOthersBestRuns = true,
	partyPlayerNewKey = true,
	partyPlayerBestRun = true,
	guildPlayerNewKey = true,
	guildPlayerBestRun = true,
	partyTabEnabled = true,
	partyTabShowKeyless = true,
	guildOnlineTabEnabled = true,
	guildOnlineTabShowKeyless = true,
	guildAllTabEnabled = true,
	guildAllTabShowKeyless = false,
	keystones = {}
}

local optionsGeneral = {
	name = "|cff00ccffKeystone Roll-Call|r by Strucker",
	type = 'group',
	desc = "",
	set = 	SetValue,
	get = 	GetValue,
	handler = KeystoneRollCall,
	args = {
		["SHOW_MINIMAP_BUTTON"] = {
			name = "Show Minimap Button",
			type = 'toggle',
			order = 50,
			set = function(info,val) 
				KeystoneRollCall.db.global.minimapIcon.hide = not val 
				if val then
					KeystoneRollCall.icon:Show("Keystone Roll-Call")
				else
					KeystoneRollCall.icon:Hide("Keystone Roll-Call")
				end
			
			end,
			get = function(info) return not KeystoneRollCall.db.global.minimapIcon.hide end,
			arg = "",
		},
		["CONSOLE_PRINT"] = {
			name = "Console Messages",
			type = 'group',
			order = 100,
			guiInline = true,
			args = {
				["NEW_KEY_LOCAL"] = {
					name = "Print to console your new keys",
					type = 'toggle',
					width  = 'full',
					order = 120,
					arg = "printPlayerNewKey",
					disabled = false,
				},
				["NEW_BEST_RUN_LOCAL"] = {
					name = "Print to console the new weekly best mythic+ runs you achieve",
					type = 'toggle',
					width  = 'full',
					order = 140,
					arg = "printPlayerBestRun",
					disabled = false,
				},
				["NEW_KEY_OTHERS"] = {
					name = "Print to console the new keys aquired by others",
					type = 'toggle',
					width  = 'full',
					order = 160,
					arg = "printOthersNewKeys",
					disabled = false,
				},
				["NEW_BEST_RUN_OTHERS"] = {
					name = "Print to console the new weekly best mythic+ runs achieved by others",
					type = 'toggle',
					width  = 'full',
					order = 180,
					arg = "printOthersBestRuns",
					disabled = false,
				}
			}
		},
		["Announcements"] = {
			name = "Announcements",
			type = 'group',
			order = 300,
			guiInline = true,
			args = {
				["NEW_KEY_PARTY"] = {
					name = "Announce to party chat your new keys",
					type = 'toggle',
					width  = 'full',
					order = 320,
					arg = "partyPlayerNewKey",
					disabled = false,
				},
				["NEW_BEST_RUN_PARTY"] = {
					name = "Announce to party chat the new weekly best mythic+ runs you achieve",
					type = 'toggle',
					width  = 'full',
					order = 340,
					arg = "partyPlayerBestRun",
					disabled = false,
				},
				["NEW_KEY_GUILD"] = {
					name = "Announce to guild chat your new keys",
					type = 'toggle',
					width  = 'full',
					order = 360,
					arg = "guildPlayerNewKey",
					disabled = false,
				},
				["NEW_BEST_RUN_GUILD"] = {
					name = "Announce to guild chat the new weekly best mythic+ runs you achieve",
					type = 'toggle',
					width  = 'full',
					order = 380,
					arg = "guildPlayerBestRun",
					disabled = false,
				}
			}
		},
		["PARTY_RAID_DISPLAY"] = {
			name = "Party/Raid Keystones Display",
			type = 'group',
			order = 500,
			guiInline = true,
			args = {
				["ENABLE"] = {
					name = "Enable",
					type = 'toggle',
					width  = 'full',
					order = 520,
					arg = "partyTabEnabled",
					disabled = false,
				},
				["SHOW_KEYLESS"] = {
					name = "List members without known keystones",
					type = 'toggle',
					width  = 'full',
					order = 540,
					arg = "partyTabShowKeyless",
					disabled = false,
				}
			}
		},
		["GUILD_ONLINE_DISPLAY"] = {
			name = "Guild (Online) Keystones Display",
			type = 'group',
			order = 700,
			guiInline = true,
			args = {
				["ENABLE"] = {
					name = "Enable",
					type = 'toggle',
					width  = 'full',
					order = 720,
					arg = "guildOnlineTabEnabled",
					disabled = false,
				},
				["SHOW_KEYLESS"] = {
					name = "List members without known keystones",
					type = 'toggle',
					width  = 'full',
					order = 740,
					arg = "guildOnlineTabShowKeyless",
					disabled = false,
				}
			}
		},
		["GUILD_ALL_DISPLAY"] = {
			name = "Guild (All) Keystones Display",
			type = 'group',
			order = 900,
			guiInline = true,
			args = {
				["ENABLE"] = {
					name = "Enable",
					type = 'toggle',
					width  = 'full',
					order = 920,
					arg = "guildAllTabEnabled",
					disabled = false,
				},
				["SHOW_KEYLESS"] = {
					name = "List members without known keystones",
					type = 'toggle',
					width  = 'full',
					order = 940,
					arg = "guildAllTabShowKeyless",
					disabled = false,
				}
			}
		},
	}
}

function KeystoneRollCall:RegisterSettings()
	self.db = LibStub('AceDB-3.0'):New('KRCDB', {global=defaultOptions}, 'Default')
	print ("partyTabEnabled",self.db.global.partyTabEnabled)
	if self.db.global.version ~= defaultOptions.version then
		print("old Settings")
	end
	
	
	local title = "Keystone Roll-Call"

	local dialog = LibStub('AceConfigDialog-3.0')
	KeystoneRollCall.Registry:RegisterOptionsTable("KeystoneRollCall", {name = "",type = 'group',desc = "",args = {}})
	local dummy = dialog:AddToBlizOptions("KeystoneRollCall", title)
	dummy:SetScript('OnShow', function(self)
		InterfaceOptionsFrame_OpenToCategory(KeystoneRollCall.generalOptions)
	end)

	KeystoneRollCall.Registry:RegisterOptionsTable("KeystoneRollCall-General", optionsGeneral)
	KeystoneRollCall.generalOptions = dialog:AddToBlizOptions("KeystoneRollCall-General", "General Settings", title)

	KeystoneRollCall.Registry:RegisterOptionsTable("KeystoneRollCall-Launch", {name = "",type = 'group',desc = "",args = {}})
	KeystoneRollCall.launchOptions = dialog:AddToBlizOptions("KeystoneRollCall-Launch", "Launch", title)
	KeystoneRollCall.launchOptions:SetScript('OnShow', function(self)
		InterfaceOptionsFrame:Hide()
		KeystoneRollCall:Show()
	end)
	
	
	
	
	
	
	
	if not self.db.global.minimapIcon then
		self.db.global.minimapIcon = {}
	end
		
	local dataobj = LibStub:GetLibrary('LibDataBroker-1.1'):NewDataObject(title, {
		type = 'launcher',
		text = title,
		label = title,
		icon = 'Interface\\Icons\\Ability_hunter_beastcall',
	})
	
	dataobj.OnClick = function(self,button,down) 
		if not KeystoneRollCall.frame or not KeystoneRollCall.frame:IsVisible() then
			KeystoneRollCall:Show()
		else
			KeystoneRollCall.frame:Hide()
		end
	end
	
	dataobj.OnTooltipShow = function(tooltip)
		KeystoneRollCall:DoSort()
		tooltip:AddLine(title)
		tooltip:AddLine(" ")
		
		
		for i, keystone in ipairs(self.db.global.keystones) do
			if keystone.dungeon and tonumber(keystone.dungeon) > 0 and keystone.isPlayers then
				tooltip:AddDoubleLine("+".. KeystoneRollCall:colorLevelDifficulty(keystone.level,keystone.level) .. " " ..KeystoneRollCall:getDungeonName(keystone.dungeon),KeystoneRollCall.CLASS_COLOR_CODES[keystone.class] .. keystone.name .."|r");
			end
		end
	end
	
	self.icon = LibStub("LibDBIcon-1.0", true)
	self.icon:Register(title, dataobj, self.db.global.minimapIcon)
end
